@@ -1,6 +1,6 @@
 .NAMES = LETTERS[c(1:8, 10:26)]
-setClass("doeFactor", representation = representation(low = "ANY", high = "ANY", name = "character", unit = "character", type = "character"), prototype = prototype(low = -1, 
-    high = 1, name = "", unit = "", type = "numeric"))
+setClass("doeFactor", representation = representation(low = "ANY", high = "ANY", name = "character", unit = "character", 
+    type = "character"), prototype = prototype(low = -1, high = 1, name = "", unit = "", type = "numeric"))
 setGeneric(".low", function(object) standardGeneric(".low"))
 setGeneric(".low<-", function(x, value) standardGeneric(".low<-"))
 setMethod(".low", "doeFactor", function(object) unlist(object@low))
@@ -62,9 +62,10 @@ setMethod("show", signature(object = "doeFactor"), function(object) {
     cat("type: ", .type(object), "\n")
     cat("\n")
 })
-setClass(Class = "facDesign", representation = representation(name = "character", factors = "list", cube = "data.frame", star = "data.frame", centerCube = "data.frame", 
-    centerStar = "data.frame", generator = "ANY", response = "data.frame", block = "data.frame", blockGen = "data.frame", runOrder = "data.frame", standardOrder = "data.frame", 
-    desireVal = "list", desirability = "list", fits = "list"))
+setClass(Class = "facDesign", representation = representation(name = "character", factors = "list", cube = "data.frame", 
+    star = "data.frame", centerCube = "data.frame", centerStar = "data.frame", generator = "ANY", response = "data.frame", 
+    block = "data.frame", blockGen = "data.frame", runOrder = "data.frame", standardOrder = "data.frame", desireVal = "list", 
+    desirability = "list", fits = "list"))
 setGeneric(".nfp", function(object) standardGeneric(".nfp"))
 setMethod(".nfp", "facDesign", function(object) {
     x = factors(object)
@@ -511,10 +512,11 @@ setReplaceMethod("response", "facDesign", function(object, value) {
         stop("vector or data.frame expected!")
     if (is.vector(value) && (is.numeric(value) || is.na(value))) {
         if (nrow(response(object)) != length(value)) 
-            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), " "))
+            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), 
+                " "))
         object@response <- data.frame(value)
         object@response[index, ] <- value
-        names(object@response) = deparse(substitute(value))
+        names(object@response) = make.names(deparse(substitute(value)))
         return(object)
     }
     if (is.data.frame(value)) {
@@ -538,7 +540,8 @@ setReplaceMethod("blockGen", "facDesign", function(object, value) {
         stop("vector or data.frame expected!")
     if (is.vector(value) && (is.numeric(value) || is.na(value))) {
         if (nrow(object) != length(value)) 
-            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), " "))
+            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), 
+                " "))
         object@blockGen <- as.data.frame(value)
         names(blockGen(object)) = deparse(substitute(value))
         object
@@ -563,7 +566,8 @@ setReplaceMethod("block", "facDesign", function(object, value) {
         stop("vector or data.frame expected!")
     if (is.vector(value) && (is.numeric(value) || is.na(value))) {
         if (nrow(object) != length(value)) 
-            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), " "))
+            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), 
+                " "))
         object@block <- as.data.frame(value)
         names(block(object)) = deparse(substitute(value))
         object
@@ -694,11 +698,14 @@ setMethod("summary", signature(object = "facDesign"), function(object) {
     doeFactors = factors(object)
     cat("Information about the factors:\n\n")
     .nfp(object)
-    cat("\n-----------\n")
+    cat("-----------\n")
     print(as.data.frame(object))
-    cat("\n---------\n\n")
-    identity(object)
-    cat("\n")
+    temp = aliasTable(object, show = FALSE)
+    if (ncol(temp) > 0) {
+        cat("\n---------\n\n")
+        identity(object)
+        cat("\n")
+    }
     invisible(as.data.frame(object))
 })
 .identityOld = function(x, DB = FALSE) {
@@ -884,7 +891,8 @@ confounds = function(x, depth = 2) {
     }
     cat("\nAlias Structure:\n")
     for (i in 1:length(effect1)) {
-        if ((length(strsplit(effect1[i], split = character(0))[[1]]) <= depth) && (length(strsplit(effect2[i], split = character(0))[[1]]) <= depth)) 
+        if ((length(strsplit(effect1[i], split = character(0))[[1]]) <= depth) && (length(strsplit(effect2[i], split = character(0))[[1]]) <= 
+            depth)) 
             cat(effect1[i], "\tis confounded with\t", effect2[i], "\n")
         if (identical(depth, "all")) 
             cat(effect1[i], "\tis confounded with\t", effect2[i], "\n")
